<?php
/*
Plugin Name: WPUrgencyBuilder
Description: Displays a message with an initial number defined between ## and dynamically updates it every 3 to 6 seconds, adding or subtracting a random value within a specified range.
Version: 1.4
Author: SellingSoftware.rocks
*/

function random_viewers_shortcode($atts) {
    // Atributos del shortcode
    $atts = shortcode_atts(
        array(
            'message' => '#100# are watching this video.',
            'range' => '1-20',
        ),
        $atts,
        'randomviewers'
    );

    // Extrae el mensaje y el rango
    $message = $atts['message'];
    $range = explode('-', $atts['range']);

    // Obtén el valor mínimo y máximo del rango
    $min_change = isset($range[0]) ? (int)$range[0] : 1;
    $max_change = isset($range[1]) ? (int)$range[1] : 20;

    // Extrae el valor base definido entre ##
    preg_match('/#(\d+)#/', $message, $matches);
    $base_number = isset($matches[1]) ? (int)$matches[1] : 100;

    // Genera un valor inicial aleatorio sumando/restando al valor base
    $initial_number = $base_number + rand(-$max_change, $max_change);

    // Reemplaza ## en el mensaje por el número inicial modificado
    $updated_message = preg_replace('/#\d+#/', $initial_number, $message);

    // Prepara el contenedor para el mensaje dinámico
    $html = "<span id='random-viewers-message'>$updated_message</span>";

    // Genera el script de actualización
    $html .= "
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            var baseValue = $base_number;
            var minChange = $min_change;
            var maxChange = $max_change;
            var messageTemplate = " . json_encode($message) . ";

            function updateRandomViewers() {
                // Genera un valor aleatorio para sumar/restar al valor base
                var change = Math.floor(Math.random() * (maxChange - minChange + 1) + minChange) * (Math.random() < 0.5 ? -1 : 1);
                var newValue = Math.max(0, baseValue + change); // Asegura que no sea negativo
                var updatedMessage = messageTemplate.replace(/#\\d+#/, newValue);
                document.getElementById('random-viewers-message').textContent = updatedMessage;

                // Programa la próxima actualización con un intervalo aleatorio 
                var nextInterval = Math.floor(Math.random() * (6000 - 3000 + 1) + 5000); 
                setTimeout(updateRandomViewers, nextInterval);
            }

            // Inicia la primera actualización después de un intervalo aleatorio
            var initialInterval = Math.floor(Math.random() * (3000 - 2000 + 1) + 2000);
            setTimeout(updateRandomViewers, initialInterval);
        });
    </script>";

    return $html;
}

// Registrar el shortcode
add_shortcode('randomviewers', 'random_viewers_shortcode');
